@@ -28,16 +28,12 @@ G_BEGIN_DECLS
 
 #define GCAL_TYPE_CALENDAR_MANAGEMENT_PAGE (gcal_calendar_management_page_get_type ())
 
-G_DECLARE_INTERFACE (GcalCalendarManagementPage, gcal_calendar_management_page, GCAL, CALENDAR_MANAGEMENT_PAGE, GtkWidget)
+G_DECLARE_INTERFACE (GcalCalendarManagementPage, gcal_calendar_management_page, GCAL, CALENDAR_MANAGEMENT_PAGE, AdwNavigationPage)
 
 struct _GcalCalendarManagementPageInterface
 {
   GTypeInterface parent;
 
-  const gchar*       (*get_name)                                 (GcalCalendarManagementPage *self);
-
-  const gchar*       (*get_title)                                (GcalCalendarManagementPage *self);
-
   void               (*activate)                                 (GcalCalendarManagementPage *self,
                                                                   GcalCalendar               *calendar);
 
@@ -48,10 +44,6 @@ struct _GcalCalendarManagementPageInterface
                                                                   GcalCalendar               *calendar);
 };
 
-const gchar*         gcal_calendar_management_page_get_name      (GcalCalendarManagementPage *self);
-
-const gchar*         gcal_calendar_management_page_get_title     (GcalCalendarManagementPage *self);
-
 void                 gcal_calendar_management_page_activate      (GcalCalendarManagementPage *self,
                                                                   GcalCalendar               *calendar);
 
