@@ -36,7 +36,6 @@ struct _GcalEditCalendarPage
   GtkColorDialogButton *calendar_color_button;
   AdwSwitchRow       *calendar_visible_row;
   AdwActionRow       *calendar_url_row;
-  AdwSwitchRow       *default_row;
   AdwEntryRow        *name_entry;
   GtkWidget          *remove_group;
 
@@ -122,10 +121,6 @@ static void
 setup_calendar (GcalEditCalendarPage *self,
                 GcalCalendar         *calendar)
 {
-  g_autofree gchar *parent_name = NULL;
-  GcalCalendar *default_calendar;
-  GcalManager *manager;
-  ESource *default_source;
   ESource *source;
   gboolean is_remote;
   gboolean is_file;
@@ -133,16 +128,11 @@ setup_calendar (GcalEditCalendarPage *self,
 
   self->calendar = g_object_ref (calendar);
 
-  manager = gcal_context_get_manager (self->context);
-  default_calendar = gcal_manager_get_default_calendar (manager);
-  default_source = gcal_calendar_get_source (default_calendar);
   is_goa = is_goa_calendar (self, calendar);
   source = gcal_calendar_get_source (calendar);
   is_file = e_source_has_extension (source, E_SOURCE_EXTENSION_LOCAL_BACKEND);
   is_remote = is_remote_source (source);
 
-  get_source_parent_name_color (manager, source, &parent_name, NULL);
-
   GCAL_TRACE_MSG ("Calendar '%s' is GOA: %d; is file: %d; is remote: %d",
                   gcal_calendar_get_name (calendar),
                   is_goa,
@@ -197,10 +187,9 @@ setup_calendar (GcalEditCalendarPage *self,
 
   if (is_goa)
     {
-      g_autofree gchar *name = NULL;
+      const gchar *parent_name = e_source_get_display_name (gcal_calendar_get_parent_source (calendar));
 
-      get_source_parent_name_color (manager, source, &name, NULL);
-      adw_action_row_set_subtitle (self->account_row, name);
+      adw_action_row_set_subtitle (self->account_row, parent_name);
     }
 
   if (!is_goa && !is_remote && !is_file)
@@ -213,39 +202,29 @@ setup_calendar (GcalEditCalendarPage *self,
   gtk_editable_set_text (GTK_EDITABLE (self->name_entry), gcal_calendar_get_name (calendar));
   adw_switch_row_set_active (self->calendar_visible_row, gcal_calendar_get_visible (calendar));
 
-  adw_switch_row_set_active (self->default_row, source == default_source);
-  gtk_widget_set_visible (GTK_WIDGET (self->default_row), !gcal_calendar_is_read_only (calendar));
   gtk_widget_set_visible (self->remove_group, e_source_get_removable (source));
 }
 
-static void
-update_calendar (GcalEditCalendarPage *self)
-{
-  GcalManager *manager;
-  const GdkRGBA *color;
-
-  GCAL_ENTRY;
-
-  g_assert (self->calendar != NULL);
-
-  manager = gcal_context_get_manager (self->context);
-  color = gtk_color_dialog_button_get_rgba (self->calendar_color_button);
-
-  gcal_calendar_set_visible (self->calendar, adw_switch_row_get_active (self->calendar_visible_row));
-  gcal_calendar_set_name (self->calendar, gtk_editable_get_text (GTK_EDITABLE (self->name_entry)));
-  gcal_calendar_set_color (self->calendar, color);
-
-  if (adw_switch_row_get_active (self->default_row))
-    gcal_manager_set_default_calendar (manager, self->calendar);
-
-  GCAL_EXIT;
-}
-
-
 /*
  * Callbacks
  */
 
+static void
+on_calendar_color_changed_cb (GtkColorDialogButton *button,
+                              GParamSpec           *pspec,
+                              GcalEditCalendarPage *self)
+{
+  gcal_calendar_set_color (self->calendar, gtk_color_dialog_button_get_rgba (button));
+}
+
+static void
+on_calendar_visibility_changed_cb (AdwSwitchRow         *row,
+                                   GParamSpec           *pspec,
+                                   GcalEditCalendarPage *self)
+{
+  gcal_calendar_set_visible (self->calendar, adw_switch_row_get_active (row));
+}
+
 static void
 on_remove_button_row_activated_cb (GtkButton            *button,
                                    GcalEditCalendarPage *self)
@@ -313,7 +292,7 @@ gcal_edit_calendar_page_deactivate (GcalCalendarManagementPage *page)
 
   self = GCAL_EDIT_CALENDAR_PAGE (page);
 
-  update_calendar (self);
+  gcal_calendar_set_name (self->calendar, gtk_editable_get_text (GTK_EDITABLE (self->name_entry)));
 
   manager = gcal_context_get_manager (self->context);
   gcal_manager_save_source (manager, gcal_calendar_get_source (self->calendar));
@@ -335,6 +314,17 @@ gcal_calendar_management_page_iface_init (GcalCalendarManagementPageInterface *i
  * GObject overrides
  */
 
+static void
+gcal_edit_calendar_page_dispose (GObject *object)
+{
+  GcalEditCalendarPage *self = GCAL_EDIT_CALENDAR_PAGE (object);
+
+  if (self->calendar)
+    gcal_calendar_set_name (self->calendar, gtk_editable_get_text (GTK_EDITABLE (self->name_entry)));
+
+  G_OBJECT_CLASS (gcal_edit_calendar_page_parent_class)->dispose (object);
+}
+
 static void
 gcal_edit_calendar_page_finalize (GObject *object)
 {
@@ -391,6 +381,7 @@ gcal_edit_calendar_page_class_init (GcalEditCalendarPageClass *klass)
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
   GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
+  object_class->dispose = gcal_edit_calendar_page_dispose;
   object_class->finalize = gcal_edit_calendar_page_finalize;
   object_class->get_property = gcal_edit_calendar_page_get_property;
   object_class->set_property = gcal_edit_calendar_page_set_property;
@@ -403,10 +394,11 @@ gcal_edit_calendar_page_class_init (GcalEditCalendarPageClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GcalEditCalendarPage, calendar_color_button);
   gtk_widget_class_bind_template_child (widget_class, GcalEditCalendarPage, calendar_url_row);
   gtk_widget_class_bind_template_child (widget_class, GcalEditCalendarPage, calendar_visible_row);
-  gtk_widget_class_bind_template_child (widget_class, GcalEditCalendarPage, default_row);
   gtk_widget_class_bind_template_child (widget_class, GcalEditCalendarPage, name_entry);
   gtk_widget_class_bind_template_child (widget_class, GcalEditCalendarPage, remove_group);
 
+  gtk_widget_class_bind_template_callback (widget_class, on_calendar_color_changed_cb);
+  gtk_widget_class_bind_template_callback (widget_class, on_calendar_visibility_changed_cb);
   gtk_widget_class_bind_template_callback (widget_class, on_remove_button_row_activated_cb);
   gtk_widget_class_bind_template_callback (widget_class, on_settings_button_clicked_cb);
 }
