@@ -1,4 +1,6 @@
-/* GTK - The GIMP Toolkit
+/* gcal-multi-choice.c
+ *
+ * GTK - The GIMP Toolkit
  *
  * Copyright (C) 2015 Red Hat, Inc.
  *
@@ -24,25 +26,29 @@
 
 struct _GcalMultiChoice
 {
-  GtkBox parent;
-  GtkWidget *down_button;
-  GtkWidget *button;
-  GtkStack *stack;
-  GtkWidget *up_button;
-  gint value;
-  gint min_value;
-  gint max_value;
-  gboolean wrap;
-  gboolean animate;
-  GtkWidget **choices;
-  gint n_choices;
-  GtkWidget *active;
-  GtkWidget *label1;
-  GtkWidget *label2;
-  GtkWidget *popover;
-  GcalMultiChoiceFormatCallback format_cb;
-  gpointer                      format_data;
-  GDestroyNotify                format_destroy;
+  GtkBox                          parent;
+
+  GtkWidget                      *down_button;
+  GtkWidget                      *button;
+  GtkStack                       *stack;
+  GtkWidget                      *up_button;
+  GtkWidget                      *label1;
+  GtkWidget                      *label2;
+
+  gint                            value;
+  gint                            min_value;
+  gint                            max_value;
+  gboolean                        wrap;
+  gboolean                        animate;
+
+  GtkWidget                     **choices;
+  gint                            n_choices;
+  GtkWidget                      *active;
+  GtkWidget                      *popover;
+
+  GcalMultiChoiceFormatCallback   format_cb;
+  gpointer                        format_data;
+  GDestroyNotify                  format_destroy;
 };
 
 enum
@@ -67,11 +73,21 @@ enum
 static guint signals[LAST_SIGNAL] = { 0, };
 static GParamSpec *properties[NUM_PROPERTIES] = { NULL, };
 
-G_DEFINE_TYPE (GcalMultiChoice, gcal_multi_choice, GTK_TYPE_BOX)
+static void gcal_multi_choice_accessible_init (GtkAccessibleInterface *iface);
+
+static void gcal_multi_choice_accessible_range_init (GtkAccessibleRangeInterface *iface);
+
+G_DEFINE_TYPE_WITH_CODE (GcalMultiChoice, gcal_multi_choice, GTK_TYPE_BOX,
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_ACCESSIBLE, gcal_multi_choice_accessible_init)
+                         G_IMPLEMENT_INTERFACE (GTK_TYPE_ACCESSIBLE_RANGE, gcal_multi_choice_accessible_range_init))
+
+/*
+ * Auxiliary methods
+ */
 
 static gchar *
 get_value_string (GcalMultiChoice *self,
-                  gint            value)
+                  gint             value)
 {
   if (self->format_cb)
     return self->format_cb (self, value, self->format_data);
@@ -102,6 +118,9 @@ apply_value (GcalMultiChoice        *self,
 
   text = get_value_string (self, self->value);
   gtk_label_set_text (GTK_LABEL (label), text);
+  gtk_accessible_update_property (GTK_ACCESSIBLE (self),
+                                  GTK_ACCESSIBLE_PROPERTY_VALUE_TEXT, text,
+                                  -1);
   g_free (text);
 
   if (!self->animate)
@@ -117,8 +136,8 @@ apply_value (GcalMultiChoice        *self,
 
 static void
 set_value (GcalMultiChoice         *self,
-           gint                    value,
-           GtkStackTransitionType  transition)
+           gint                     value,
+           GtkStackTransitionType   transition)
 {
   value = CLAMP (value, self->min_value, self->max_value);
 
@@ -129,6 +148,12 @@ set_value (GcalMultiChoice         *self,
 
   apply_value (self, transition);
 
+  gtk_accessible_update_property (GTK_ACCESSIBLE (self),
+                                  GTK_ACCESSIBLE_PROPERTY_VALUE_MAX, (gdouble) self->max_value,
+                                  GTK_ACCESSIBLE_PROPERTY_VALUE_MIN, (gdouble) self->min_value,
+                                  GTK_ACCESSIBLE_PROPERTY_VALUE_NOW, (gdouble) self->value,
+                                  -1);
+
   g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_VALUE]);
 }
 
@@ -185,28 +210,82 @@ update_sensitivity (GcalMultiChoice *self)
 
   gtk_widget_set_can_target (self->button, has_popup);
 
-  gtk_accessible_update_property (GTK_ACCESSIBLE (self->button),
+  gtk_accessible_update_property (GTK_ACCESSIBLE (self),
                                   GTK_ACCESSIBLE_PROPERTY_HAS_POPUP, has_popup,
                                   -1);
   if (self->popover != NULL)
-    gtk_accessible_update_relation (GTK_ACCESSIBLE (self->button),
+    gtk_accessible_update_relation (GTK_ACCESSIBLE (self),
                                     GTK_ACCESSIBLE_RELATION_CONTROLS, self->popover, NULL,
                                     -1);
   else
-    gtk_accessible_reset_relation (GTK_ACCESSIBLE (self->button),
+    gtk_accessible_reset_relation (GTK_ACCESSIBLE (self),
                                    GTK_ACCESSIBLE_RELATION_CONTROLS);
 }
 
 static void
-button_clicked_cb (GtkWidget      *button,
+button_clicked_cb (GtkWidget       *button,
                    GcalMultiChoice *self)
 {
+  GtkStateFlags state_flags;
+
+  state_flags = gtk_widget_get_state_flags (button);
+
   if (button == self->down_button)
     go_down (self);
   else if (button == self->up_button)
     go_up (self);
   else
     g_assert_not_reached ();
+
+  if (!gtk_widget_grab_focus (GTK_WIDGET (self)))
+    g_assert_not_reached ();
+
+  gtk_widget_set_state_flags (button, state_flags, TRUE);
+}
+
+static gboolean
+key_pressed_cb (GcalMultiChoice       *self,
+                guint                  keyval,
+                guint                  keycode,
+                GdkModifierType        state,
+                GtkEventControllerKey *event_controller)
+{
+  gboolean is_active;
+  gint old_value;
+
+  g_assert (GCAL_IS_MULTI_CHOICE (self));
+  g_assert (GTK_IS_EVENT_CONTROLLER_KEY (event_controller));
+
+  switch (keyval)
+    {
+    case GDK_KEY_space:
+    case GDK_KEY_KP_Space:
+    case GDK_KEY_Return:
+    case GDK_KEY_ISO_Enter:
+    case GDK_KEY_KP_Enter:
+      is_active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (self->button));
+      if (self->popover)
+        gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (self->button), !is_active);
+      return TRUE;
+
+    case GDK_KEY_Up:
+    case GDK_KEY_KP_Up:
+      old_value = self->value;
+      go_up (self);
+      if (old_value == self->value)
+        gtk_widget_error_bell (GTK_WIDGET (self));
+      return TRUE;
+
+    case GDK_KEY_Down:
+    case GDK_KEY_KP_Down:
+      old_value = self->value;
+      go_down (self);
+      if (old_value == self->value)
+        gtk_widget_error_bell (GTK_WIDGET (self));
+      return TRUE;
+    }
+
+  return FALSE;
 }
 
 static void
@@ -247,13 +326,22 @@ popover_destroy_cb (GcalMultiChoice *menu_button)
 }
 
 static void
-gcal_multi_choice_init (GcalMultiChoice *self)
+button_state_flags_changed_cb (GcalMultiChoice *self,
+                               GtkStateFlags    previous_state_flags)
 {
-  gtk_widget_init_template (GTK_WIDGET (self));
+  GtkStateFlags state_flags;
 
-  update_sensitivity (self);
+  g_assert (GCAL_IS_MULTI_CHOICE (self));
+
+  state_flags = gtk_widget_get_state_flags (self->button);
+
+  gtk_widget_set_state_flags (GTK_WIDGET (self), state_flags, TRUE);
 }
 
+/*
+ * GObject overrides
+ */
+
 static void
 gcal_multi_choice_dispose (GObject *object)
 {
@@ -285,9 +373,9 @@ gcal_multi_choice_dispose (GObject *object)
 
 static void
 gcal_multi_choice_get_property (GObject    *object,
-                               guint       property_id,
-                               GValue     *value,
-                               GParamSpec *pspec)
+                                guint       property_id,
+                                GValue     *value,
+                                GParamSpec *pspec)
 {
   GcalMultiChoice *self = GCAL_MULTI_CHOICE (object);
 
@@ -325,9 +413,9 @@ gcal_multi_choice_get_property (GObject    *object,
 
 static void
 gcal_multi_choice_set_property (GObject      *object,
-                               guint         property_id,
-                               const GValue *value,
-                               GParamSpec   *pspec)
+                                guint         property_id,
+                                const GValue *value,
+                                GParamSpec   *pspec)
 {
   GcalMultiChoice *self = GCAL_MULTI_CHOICE (object);
 
@@ -375,7 +463,7 @@ gcal_multi_choice_set_property (GObject      *object,
 
 static void
 gcal_multi_choice_notify (GObject    *object,
-                        GParamSpec *pspec)
+                          GParamSpec *pspec)
 {
   if (strcmp (pspec->name, "focus-on-click") == 0)
     {
@@ -389,11 +477,20 @@ gcal_multi_choice_notify (GObject    *object,
     G_OBJECT_CLASS (gcal_multi_choice_parent_class)->notify (object, pspec);
 }
 
+/*
+ * GtkWidget overrides
+ */
+
 static void
 gcal_multi_choice_state_flags_changed (GtkWidget    *widget,
-                                     GtkStateFlags previous_state_flags)
+                                       GtkStateFlags previous_state_flags)
 {
   GcalMultiChoice *self = GCAL_MULTI_CHOICE (widget);
+  GtkStateFlags state_flags;
+
+  state_flags = gtk_widget_get_state_flags (widget);
+  if (state_flags & GTK_STATE_FLAG_FOCUSED)
+    gtk_widget_set_state_flags (widget, GTK_STATE_FLAG_FOCUS_VISIBLE, FALSE);
 
   if (!gtk_widget_is_sensitive (widget))
     {
@@ -404,12 +501,12 @@ gcal_multi_choice_state_flags_changed (GtkWidget    *widget,
 
 static void
 gcal_multi_choice_measure (GtkWidget      *widget,
-                         GtkOrientation  orientation,
-                         int             for_size,
-                         int            *minimum,
-                         int            *natural,
-                         int            *minimum_baseline,
-                         int            *natural_baseline)
+                           GtkOrientation  orientation,
+                           int             for_size,
+                           int            *minimum,
+                           int            *natural,
+                           int            *minimum_baseline,
+                           int            *natural_baseline)
 {
   GcalMultiChoice *self = GCAL_MULTI_CHOICE (widget);
 
@@ -423,9 +520,9 @@ gcal_multi_choice_measure (GtkWidget      *widget,
 
 static void
 gcal_multi_choice_size_allocate (GtkWidget *widget,
-                               int        width,
-                               int        height,
-                               int        baseline)
+                                 int        width,
+                                 int        height,
+                                 int        baseline)
 {
   GcalMultiChoice *self= GCAL_MULTI_CHOICE (widget);
 
@@ -438,7 +535,7 @@ gcal_multi_choice_size_allocate (GtkWidget *widget,
 
 static gboolean
 gcal_multi_choice_focus (GtkWidget        *widget,
-                       GtkDirectionType  direction)
+                         GtkDirectionType  direction)
 {
   GcalMultiChoice *self = GCAL_MULTI_CHOICE (widget);
 
@@ -456,6 +553,35 @@ gcal_multi_choice_grab_focus (GtkWidget *widget)
   return gtk_widget_grab_focus (self->button);
 }
 
+/*
+ * GtkAccessible overrides
+ */
+
+static gboolean
+gcal_multi_choice_accessible_get_platform_state (GtkAccessible              *accessible,
+                                                 GtkAccessiblePlatformState  state)
+{
+  GcalMultiChoice *self = GCAL_MULTI_CHOICE (accessible);
+
+  return gtk_accessible_get_platform_state (GTK_ACCESSIBLE (self->button), state);
+}
+
+/*
+ * GtkAccessibleRange overrides
+ */
+
+static gboolean
+gcal_multi_choice_accessible_range_set_current_value (GtkAccessibleRange *accessible_range,
+                                                      gdouble             value)
+{
+  gcal_multi_choice_set_value (GCAL_MULTI_CHOICE (accessible_range), value);
+  return TRUE;
+}
+
+/*
+ * Init
+ */
+
 static void
 gcal_multi_choice_class_init (GcalMultiChoiceClass *class)
 {
@@ -534,35 +660,96 @@ gcal_multi_choice_class_init (GcalMultiChoiceClass *class)
 
   gtk_widget_class_bind_template_callback (widget_class, button_clicked_cb);
   gtk_widget_class_bind_template_callback (widget_class, button_toggled_cb);
+  gtk_widget_class_bind_template_callback (widget_class, button_state_flags_changed_cb);
+  gtk_widget_class_bind_template_callback (widget_class, key_pressed_cb);
 
   gtk_widget_class_set_css_name (widget_class, "navigator");
 }
 
+static void
+gcal_multi_choice_accessible_init (GtkAccessibleInterface *iface)
+{
+  iface->get_platform_state = gcal_multi_choice_accessible_get_platform_state;
+}
+
+static void
+gcal_multi_choice_accessible_range_init (GtkAccessibleRangeInterface *iface)
+{
+  iface->set_current_value = gcal_multi_choice_accessible_range_set_current_value;
+}
+
+static void
+gcal_multi_choice_init (GcalMultiChoice *self)
+{
+  gtk_widget_init_template (GTK_WIDGET (self));
+
+  update_sensitivity (self);
+}
+
+/*
+ * Public methods
+ */
+
+/**
+ * gcal_multi_choice_new:
+ *
+ * Creates a new #GcalMultiChoice.
+ *
+ * Returns: (transfer full): a newly created #GcalEventPopover
+ */
 GtkWidget *
 gcal_multi_choice_new (void)
 {
   return GTK_WIDGET (g_object_new (GCAL_TYPE_MULTI_CHOICE, NULL));
 }
 
+/**
+ * gcal_multi_choice_set_value:
+ * @self: a #GcalMultiChoice
+ * @value: the value
+ *
+ * Sets the value for @self.
+ */
 void
 gcal_multi_choice_set_value (GcalMultiChoice *self,
-                            gint            value)
+                             gint             value)
 {
+  g_assert (GCAL_IS_MULTI_CHOICE (self));
+
   set_value (self, value, GTK_STACK_TRANSITION_TYPE_NONE);
 }
 
+/**
+ * gcal_multi_choice_get_value:
+ * @self: a #GcalMultiChoice
+ *
+ * Gets the value for @self.
+ *
+ * Returns: The value for @self.
+ */
 gint
 gcal_multi_choice_get_value (GcalMultiChoice *self)
 {
+  g_assert (GCAL_IS_MULTI_CHOICE (self));
+
   return self->value;
 }
 
+/**
+ * gcal_multi_choice_set_choices:
+ * @self: a #GcalMultiChoice
+ * @choices: an array of strings
+ *
+ * Sets the available choices for @self.
+ */
 void
 gcal_multi_choice_set_choices (GcalMultiChoice  *self,
                                const gchar     **choices)
 {
   gint i;
 
+  g_assert (GCAL_IS_MULTI_CHOICE (self));
+
   for (i = 0; i < self->n_choices; i++)
     gtk_stack_remove (self->stack, self->choices[i]);
   g_free (self->choices);
@@ -581,12 +768,23 @@ gcal_multi_choice_set_choices (GcalMultiChoice  *self,
   g_object_notify_by_pspec (G_OBJECT (self), properties[PROP_CHOICES]);
 }
 
+/**
+ * gcal_multi_choice_set_format_callback:
+ * @self: a #GcalMultiChoice
+ * @callback: (nullable) (scope notified) (closure user_data) (destroy destroy): callback
+ * @user_data: user data passed to @callback
+ * @destroy: destroy notifier for @user_data
+ *
+ * Sets the format callback.
+ */
 void
 gcal_multi_choice_set_format_callback (GcalMultiChoice               *self,
                                        GcalMultiChoiceFormatCallback  callback,
                                        gpointer                       user_data,
                                        GDestroyNotify                 destroy)
 {
+  g_assert (GCAL_IS_MULTI_CHOICE (self));
+
   if (self->format_destroy)
     self->format_destroy (self->format_data);
 
@@ -597,12 +795,19 @@ gcal_multi_choice_set_format_callback (GcalMultiChoice               *self,
   apply_value (self, GTK_STACK_TRANSITION_TYPE_NONE);
 }
 
+/**
+ * gcal_multi_choice_set_popover:
+ * @self: a #GcalMultiChoice
+ * @popover: a popover widget.
+ *
+ * Sets the popover for @self.
+ */
 void
 gcal_multi_choice_set_popover (GcalMultiChoice *self,
                                GtkWidget       *popover)
 {
-  g_return_if_fail (GCAL_IS_MULTI_CHOICE (self));
-  g_return_if_fail (popover == NULL || GTK_IS_POPOVER (popover));
+  g_assert (GCAL_IS_MULTI_CHOICE (self));
+  g_assert (popover == NULL || GTK_IS_POPOVER (popover));
 
   g_object_freeze_notify (G_OBJECT (self));
 
@@ -639,10 +844,19 @@ gcal_multi_choice_set_popover (GcalMultiChoice *self,
   g_object_thaw_notify (G_OBJECT (self));
 }
 
+/**
+ * gcal_multi_choice_get_popover:
+ * @self: a #GcalMultiChoice
+ *
+ * Gets the popover for @self.
+ *
+ * Returns: (transfer none): a #GtkPopover
+ */
 GtkPopover *
 gcal_multi_choice_get_popover (GcalMultiChoice *self)
 {
-  g_return_val_if_fail (GCAL_IS_MULTI_CHOICE (self), NULL);
+  g_assert (GCAL_IS_MULTI_CHOICE (self));
 
   return GTK_POPOVER (self->popover);
 }
+
