@@ -23,6 +23,10 @@
 #include <adwaita.h>
 #include <gtk/gtk.h>
 
+#include "gcal-enums.h"
+#include "gcal-event.h"
+#include "gcal-recurrence.h"
+
 G_BEGIN_DECLS
 
 #define GCAL_TYPE_SCHEDULE_SECTION (gcal_schedule_section_get_type())
@@ -32,4 +36,9 @@ gboolean             gcal_schedule_section_recurrence_changed    (GcalScheduleSe
 
 gboolean             gcal_schedule_section_day_changed           (GcalScheduleSection *self);
 
+
+/* Tests */
+
+void gcal_schedule_section_add_tests (void);
+
 G_END_DECLS
