@@ -20,8 +20,9 @@
 #define G_LOG_DOMAIN "GcalWindow"
 
 #include "gcal-agenda-view.h"
+#include "gcal-calendar-list.h"
 #include "gcal-calendar-management-dialog.h"
-#include "gcal-calendar-button.h"
+#include "gcal-calendar-navigation-button.h"
 #include "config.h"
 #include "gcal-date-chooser.h"
 #include "gcal-debug.h"
@@ -36,7 +37,6 @@
 #include "gcal-sync-indicator.h"
 #include "gcal-timeline.h"
 #include "gcal-timeline-subscriber.h"
-#include "gcal-toolbar-end.h"
 #include "gcal-view.h"
 #include "gcal-weather-settings.h"
 #include "gcal-week-view.h"
@@ -102,8 +102,6 @@ struct _GcalWindow
   AdwApplicationWindow parent;
 
   /* upper level widgets */
-  GtkWidget              *main_box;
-
   GtkWidget              *header_bar;
   AdwToastOverlay        *overlay;
   AdwViewStack           *views_stack;
@@ -111,20 +109,19 @@ struct _GcalWindow
   GtkWidget              *month_view;
   GtkWidget              *agenda_view;
   GtkWidget              *date_chooser;
-  GtkWidget              *action_bar;
   GcalSyncIndicator      *sync_indicator;
-  GcalToolbarEnd         *toolbar_end;
-  GcalToolbarEnd         *sidebar_toolbar_end;
+  GtkWidget              *search_button;
   AdwNavigationSplitView *split_view;
 
   /* header_bar widgets */
-  GtkWidget          *calendars_button;
+  GtkWidget          *calendars_list;
   GtkWidget          *menu_button;
-  GtkWidget          *views_switcher;
 
   GcalEventEditorDialog *event_editor;
   GtkWidget             *import_dialog;
 
+  GtkWidget          *last_focused_widget;
+
   /* new event popover widgets */
   GtkWidget          *quick_add_popover;
 
@@ -203,6 +200,7 @@ update_today_action_enabled (GcalWindow *window)
     {
     case GCAL_WINDOW_VIEW_WEEK:
     case GCAL_WINDOW_VIEW_MONTH:
+    case GCAL_WINDOW_VIEW_AGENDA:
       enabled = g_date_time_get_year (window->active_date) != g_date_time_get_year (now) ||
                 g_date_time_get_week_of_year (window->active_date) !=  g_date_time_get_week_of_year (now);
 
@@ -222,6 +220,68 @@ update_today_action_enabled (GcalWindow *window)
   GCAL_EXIT;
 }
 
+static gchar*
+get_previous_date_icon (GcalWindow     *window,
+                        GcalWindowView *view)
+{
+  switch (gcal_view_get_time_direction (GCAL_VIEW (view)))
+    {
+    case GTK_ORIENTATION_VERTICAL:
+      return g_strdup ("go-up-symbolic");
+
+    case GTK_ORIENTATION_HORIZONTAL:
+      return g_strdup ("go-previous-symbolic");
+
+    default:
+      g_assert_not_reached ();
+    }
+}
+
+static gchar*
+get_previous_date_tooltip (GcalWindow  *window,
+                           const gchar *view_name)
+{
+  if (g_str_equal (view_name, "week"))
+    return g_strdup (_("Previous Week"));
+  else if (g_str_equal (view_name, "month"))
+    return g_strdup (_("Previous Month"));
+  else if (g_str_equal (view_name, "agenda"))
+    return g_strdup (_("Yesterday"));
+  else
+    g_assert_not_reached ();
+}
+
+static gchar*
+get_next_date_icon (GcalWindow     *window,
+                    GcalWindowView *view)
+{
+  switch (gcal_view_get_time_direction (GCAL_VIEW (view)))
+    {
+    case GTK_ORIENTATION_VERTICAL:
+      return g_strdup ("go-down-symbolic");
+
+    case GTK_ORIENTATION_HORIZONTAL:
+      return g_strdup ("go-next-symbolic");
+
+    default:
+      g_assert_not_reached ();
+    }
+}
+
+static gchar*
+get_next_date_tooltip (GcalWindow  *window,
+                       const gchar *view_name)
+{
+  if (g_str_equal (view_name, "week"))
+    return g_strdup (_("Next Week"));
+  else if (g_str_equal (view_name, "month"))
+    return g_strdup (_("Next Month"));
+  else if (g_str_equal (view_name, "agenda"))
+    return g_strdup (_("Tomorrow"));
+  else
+    g_assert_not_reached ();
+}
+
 static void
 maybe_add_subscribers_to_timeline (GcalWindow *self)
 {
@@ -261,9 +321,8 @@ update_active_date (GcalWindow *window,
 
   gcal_set_date_time (&window->active_date, new_date);
 
-  for (i = GCAL_WINDOW_VIEW_WEEK; i <= GCAL_WINDOW_VIEW_MONTH; i++)
+  for (i = 0; i < GCAL_WINDOW_VIEW_N_VIEWS; i++)
     gcal_view_set_date (GCAL_VIEW (window->views[i]), new_date);
-  gcal_view_set_date (GCAL_VIEW (window->agenda_view), new_date);
   gcal_view_set_date (GCAL_VIEW (window->date_chooser), new_date);
 
   update_today_action_enabled (window);
@@ -333,10 +392,20 @@ content_title (GcalWindow     *self,
                GcalWindowView  active_view)
 {
   /* We check for NULL so we get the right page name during initialization */
-  if (active_view == GCAL_WINDOW_VIEW_WEEK)
-    return g_strdup (_("Week"));
-  else
-    return g_strdup (_("Month"));
+  switch (active_view)
+    {
+    case GCAL_WINDOW_VIEW_WEEK:
+      return g_strdup (_("Week"));
+
+    case GCAL_WINDOW_VIEW_MONTH:
+      return g_strdup (_("Month"));
+
+    case GCAL_WINDOW_VIEW_AGENDA:
+      return g_strdup (_("Agenda"));
+
+    default:
+      return g_strdup (_("Calendar"));
+    }
 }
 
 static inline void
@@ -446,16 +515,21 @@ on_view_action_activated (GSimpleAction *action,
 
   view = g_variant_get_int32 (param);
 
-  /* -1 means next view */
+  /* -1 means next view, -2 means previous view */
   if (view == -1)
-    view = ++(window->active_view);
+    view = window->active_view + 1;
   else if (view == -2)
-    view = --(window->active_view);
+    view = window->active_view - 1;
 
-  window->active_view = CLAMP (view, GCAL_WINDOW_VIEW_WEEK, GCAL_WINDOW_VIEW_MONTH);
-  adw_view_stack_set_visible_child (window->views_stack, window->views[window->active_view]);
+  view = CLAMP (view, 0, GCAL_WINDOW_VIEW_N_VIEWS - 1);
 
-  g_object_notify_by_pspec (G_OBJECT (user_data), properties[PROP_ACTIVE_VIEW]);
+  if (adw_view_stack_page_get_visible (adw_view_stack_get_page (window->views_stack, window->views[view])))
+    {
+      window->active_view = view;
+      adw_view_stack_set_visible_child (window->views_stack, window->views[window->active_view]);
+
+      g_object_notify_by_pspec (G_OBJECT (user_data), properties[PROP_ACTIVE_VIEW]);
+    }
 
   GCAL_EXIT;
 }
@@ -589,6 +663,32 @@ on_window_undo_delete_event_cb (GSimpleAction *action,
   GCAL_EXIT;
 }
 
+static void
+on_breakpoint_changed (GObject *object,
+                       GParamSpec *pspec,
+                       GcalWindow *window)
+{
+  gint32 view = window->active_view;
+
+  while (!adw_view_stack_page_get_visible (adw_view_stack_get_page (window->views_stack, window->views[view])))
+    {
+      view--;
+
+      if (view < 0)
+        view += GCAL_WINDOW_VIEW_N_VIEWS;
+
+      if (view == window->active_view)
+        return;
+    }
+
+  if (window->active_view != view)
+    {
+      window->active_view = view;
+      adw_view_stack_set_visible_child (window->views_stack, window->views[window->active_view]);
+      g_object_notify_by_pspec (G_OBJECT (window), properties[PROP_ACTIVE_VIEW]);
+    }
+}
+
 static void
 view_changed (GObject    *object,
               GParamSpec *pspec,
@@ -605,6 +705,14 @@ view_changed (GObject    *object,
   if (!gtk_widget_get_visible (GTK_WIDGET (window->views_stack)))
     return;
 
+  /*
+   * As there are no guarantees for the order of AdwBreakpoint setters,
+   * it is possible that the agenda view disappears before the month and
+   * week views reappears, and vice versa.
+   */
+  if (!adw_view_stack_get_visible_child_name (window->views_stack))
+    return;
+
   eklass = g_type_class_ref (GCAL_TYPE_WINDOW_VIEW);
   eval = g_enum_get_value_by_nick (eklass, adw_view_stack_get_visible_child_name (window->views_stack));
 
@@ -754,6 +862,11 @@ event_preview_cb (GcalEventWidget        *event_widget,
 
     case GCAL_EVENT_PREVIEW_ACTION_NONE:
     default:
+      if (self->last_focused_widget)
+        {
+          gtk_root_set_focus (GTK_ROOT (self), self->last_focused_widget);
+          g_clear_weak_pointer (&self->last_focused_widget);
+        }
       break;
     }
 }
@@ -764,11 +877,27 @@ day_selected (GcalWindow *self)
   update_active_date (self, gcal_view_get_date (GCAL_VIEW (self->date_chooser)));
 }
 
+static GtkWidget*
+find_first_focusable_widget (GtkWidget *widget)
+{
+  GtkWidget *aux = widget;
+
+  while (aux && !gtk_widget_get_focusable (aux))
+    aux = gtk_widget_get_parent (aux);
+
+  g_assert (GTK_IS_WIDGET (aux));
+  return aux;
+}
+
 static void
 event_activated (GcalView        *view,
                  GcalEventWidget *event_widget,
                  gpointer         user_data)
 {
+  GcalWindow *self = GCAL_WINDOW (user_data);
+
+  g_set_weak_pointer (&self->last_focused_widget, find_first_focusable_widget (GTK_WIDGET (event_widget)));
+
   gcal_event_widget_show_preview (event_widget, event_preview_cb, user_data);
 }
 
@@ -983,7 +1112,6 @@ gcal_window_finalize (GObject *object)
     }
 
   g_clear_object (&window->context);
-  g_clear_object (&window->views_switcher);
 
   gcal_clear_date_time (&window->active_date);
 
@@ -1011,6 +1139,8 @@ gcal_window_dispose (GObject *object)
   g_clear_pointer (&self->quick_add_popover, gtk_widget_unparent);
   g_clear_pointer (&self->import_dialog, gtk_widget_unparent);
 
+  g_clear_weak_pointer (&self->last_focused_widget);
+
   if (self->delete_event_toast)
     adw_toast_dismiss (self->delete_event_toast);
 
@@ -1047,7 +1177,7 @@ gcal_window_constructed (GObject *object)
    * FIXME: this is a hack around the issue that happens when trying to bind
    * these properties using the GtkBuilder .ui file.
    */
-  g_object_bind_property (self, "context", self->calendars_button, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
+  g_object_bind_property (self, "context", self->calendars_list, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->weather_settings, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->week_view, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->month_view, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
@@ -1056,8 +1186,7 @@ gcal_window_constructed (GObject *object)
   g_object_bind_property (self, "context", self->event_editor, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->quick_add_popover, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
   g_object_bind_property (self, "context", self->sync_indicator, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
-  g_object_bind_property (self, "context", self->toolbar_end, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
-  g_object_bind_property (self, "context", self->sidebar_toolbar_end, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
+  g_object_bind_property (self, "context", self->search_button, "context", G_BINDING_DEFAULT | G_BINDING_SYNC_CREATE);
 
   /* CSS */
   load_css_providers (self);
@@ -1086,7 +1215,6 @@ gcal_window_set_property (GObject      *object,
     {
     case PROP_ACTIVE_VIEW:
       self->active_view = g_value_get_enum (value);
-      gtk_widget_set_visible (self->views[self->active_view], TRUE);
       adw_view_stack_set_visible_child (self->views_stack, self->views[self->active_view]);
       break;
 
@@ -1183,14 +1311,15 @@ gcal_window_class_init (GcalWindowClass *klass)
   GtkWidgetClass *widget_class;
 
   g_type_ensure (GCAL_TYPE_AGENDA_VIEW);
-  g_type_ensure (GCAL_TYPE_CALENDAR_BUTTON);
+  g_type_ensure (GCAL_TYPE_CALENDAR_LIST);
+  g_type_ensure (GCAL_TYPE_CALENDAR_NAVIGATION_BUTTON);
   g_type_ensure (GCAL_TYPE_DATE_CHOOSER);
   g_type_ensure (GCAL_TYPE_EVENT_EDITOR_DIALOG);
   g_type_ensure (GCAL_TYPE_MANAGER);
   g_type_ensure (GCAL_TYPE_MONTH_VIEW);
   g_type_ensure (GCAL_TYPE_QUICK_ADD_POPOVER);
   g_type_ensure (GCAL_TYPE_SYNC_INDICATOR);
-  g_type_ensure (GCAL_TYPE_TOOLBAR_END);
+  g_type_ensure (GCAL_TYPE_SEARCH_BUTTON);
   g_type_ensure (GCAL_TYPE_WEATHER_SETTINGS);
   g_type_ensure (GCAL_TYPE_WEEK_VIEW);
   g_type_ensure (GCAL_TYPE_DROP_OVERLAY);
@@ -1237,28 +1366,29 @@ gcal_window_class_init (GcalWindowClass *klass)
 
   /* widgets */
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, agenda_view);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, calendars_button);
+  gtk_widget_class_bind_template_child (widget_class, GcalWindow, calendars_list);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, date_chooser);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, event_editor);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, header_bar);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, main_box);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, menu_button);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, month_view);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, action_bar);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, quick_add_popover);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, overlay);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, sidebar_toolbar_end);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, split_view);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, sync_indicator);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, toolbar_end);
+  gtk_widget_class_bind_template_child (widget_class, GcalWindow, search_button);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, views_stack);
-  gtk_widget_class_bind_template_child (widget_class, GcalWindow, views_switcher);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, weather_settings);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, week_view);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, drop_overlay);
   gtk_widget_class_bind_template_child (widget_class, GcalWindow, drop_target);
 
+  gtk_widget_class_bind_template_callback (widget_class, on_breakpoint_changed);
   gtk_widget_class_bind_template_callback (widget_class, view_changed);
+  gtk_widget_class_bind_template_callback (widget_class, get_previous_date_icon);
+  gtk_widget_class_bind_template_callback (widget_class, get_previous_date_tooltip);
+  gtk_widget_class_bind_template_callback (widget_class, get_next_date_icon);
+  gtk_widget_class_bind_template_callback (widget_class, get_next_date_tooltip);
 
   /* Event creation related */
   gtk_widget_class_bind_template_callback (widget_class, close_new_event_widget);
@@ -1302,6 +1432,7 @@ gcal_window_init (GcalWindow *self)
 
   self->views[GCAL_WINDOW_VIEW_WEEK] = self->week_view;
   self->views[GCAL_WINDOW_VIEW_MONTH] = self->month_view;
+  self->views[GCAL_WINDOW_VIEW_AGENDA] = self->agenda_view;
 
   self->active_date = g_date_time_new_from_unix_local (0);
   self->rtl = gtk_widget_get_direction (GTK_WIDGET (self)) == GTK_TEXT_DIR_RTL;
@@ -1352,18 +1483,9 @@ void
 gcal_window_set_search_query (GcalWindow  *self,
                               const gchar *query)
 {
-  GtkWidget *search_button;
-  GcalToolbarEnd *toolbar_end;
-
   g_return_if_fail (GCAL_IS_WINDOW (self));
 
-  if (adw_navigation_split_view_get_collapsed (self->split_view))
-    toolbar_end = self->sidebar_toolbar_end;
-  else
-    toolbar_end = self->toolbar_end;
-
-  search_button = gcal_toolbar_end_get_search_button (toolbar_end);
-  gcal_search_button_search (GCAL_SEARCH_BUTTON (search_button), query);
+  gcal_search_button_search (GCAL_SEARCH_BUTTON (self->search_button), query);
 }
 
 /**
