@@ -70,6 +70,7 @@ enum
   PROP_0,
   PROP_DATE,
   PROP_CONTEXT,
+  PROP_TIME_DIRECTION,
   N_PROPS,
 };
 
@@ -546,6 +547,18 @@ on_event_widget_activated_cb (GcalEventWidget *event_widget,
   gcal_view_event_activated (GCAL_VIEW (self), event_widget);
 }
 
+static void
+on_list_box_row_activated_cb (GtkListBox     *list_box,
+                              GtkListBoxRow  *row,
+                              GcalAgendaView *self)
+{
+  GtkWidget *child = gtk_list_box_row_get_child (row);
+
+  g_assert (GCAL_IS_EVENT_WIDGET (child));
+
+  gcal_view_event_activated (GCAL_VIEW (self), GCAL_EVENT_WIDGET (child));
+}
+
 static GcalRange*
 gcal_agenda_view_get_range (GcalTimelineSubscriber *subscriber)
 {
@@ -587,10 +600,10 @@ gcal_agenda_view_add_event (GcalTimelineSubscriber *subscriber,
                          "event", event,
                          "orientation", GTK_ORIENTATION_VERTICAL,
                          "timestamp-policy", timestamp_policy,
+                         "focusable", FALSE,
                          NULL);
 
   row = g_object_new (GTK_TYPE_LIST_BOX_ROW,
-                      "activatable", FALSE,
                       "child", widget,
                       NULL);
 
@@ -598,6 +611,14 @@ gcal_agenda_view_add_event (GcalTimelineSubscriber *subscriber,
                              gcal_event_get_range (event),
                              child_data_new (row, event, self));
 
+  gtk_accessible_update_property (GTK_ACCESSIBLE (row),
+                                  GTK_ACCESSIBLE_PROPERTY_HAS_POPUP, TRUE,
+                                  -1);
+
+  gtk_accessible_update_relation (GTK_ACCESSIBLE (row),
+                                  GTK_ACCESSIBLE_RELATION_LABELLED_BY, widget, NULL,
+                                  -1);
+
   g_signal_connect (widget, "activate", G_CALLBACK (on_event_widget_activated_cb), self);
 
   gtk_list_box_append (GTK_LIST_BOX (self->list_box), row);
@@ -751,6 +772,10 @@ gcal_agenda_view_get_property (GObject    *object,
       g_value_set_object (value, self->context);
       break;
 
+    case PROP_TIME_DIRECTION:
+      g_value_set_enum (value, GTK_ORIENTATION_VERTICAL);
+      break;
+
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
       break;
@@ -770,6 +795,7 @@ gcal_agenda_view_class_init (GcalAgendaViewClass *klass)
 
   g_object_class_override_property (object_class, PROP_DATE, "active-date");
   g_object_class_override_property (object_class, PROP_CONTEXT, "context");
+  g_object_class_override_property (object_class, PROP_TIME_DIRECTION, "time-direction");
 
   gtk_widget_class_set_template_from_resource (widget_class, "/org/gnome/calendar/ui/views/gcal-agenda-view.ui");
 
@@ -777,6 +803,8 @@ gcal_agenda_view_class_init (GcalAgendaViewClass *klass)
   gtk_widget_class_bind_template_child (widget_class, GcalAgendaView, no_events_row);
   gtk_widget_class_bind_template_child (widget_class, GcalAgendaView, scrolled_window);
 
+  gtk_widget_class_bind_template_callback (widget_class, on_list_box_row_activated_cb);
+
   gtk_widget_class_set_css_name (widget_class, "agenda-view");
 }
 
