@@ -182,12 +182,15 @@ update_weather (GcalMonthCell *self)
   GcalWeatherService *weather_service;
   GcalWeatherInfo *weather_info;
   GDate date;
+  gint day_of_month;
 
   if (!self->context)
     return;
 
+  day_of_month = g_date_time_get_day_of_month (self->date);
+
   g_date_set_dmy (&date,
-                  g_date_time_get_day_of_month (self->date),
+                  day_of_month,
                   g_date_time_get_month (self->date),
                   g_date_time_get_year (self->date));
 
@@ -204,18 +207,32 @@ update_weather (GcalMonthCell *self)
   if (weather_info)
     {
       const gchar *icon_name; /* unowned */
-      const gchar *temp_str;  /* unwoned */
+      const gchar *temp_str;  /* unowned */
 
       icon_name = gcal_weather_info_get_icon_name (weather_info);
       temp_str = gcal_weather_info_get_temperature (weather_info);
 
       gtk_image_set_from_icon_name (self->weather_icon, icon_name);
       gtk_label_set_text (self->temp_label, temp_str);
+
+      /* Use a short month name label to avoid conflicting with the weather forecast's labels */
+      if (day_of_month == 1)
+        {
+          g_autofree gchar *month_name = g_date_time_format (self->date, "%b");
+          gtk_label_set_text (self->month_name_label, month_name);
+        }
     }
   else
     {
       gtk_image_clear (self->weather_icon);
       gtk_label_set_text (self->temp_label, "");
+
+      /* No risk of conflicting with the weather forecast labels in their absence, use the full month name label */
+      if (day_of_month == 1)
+        {
+          g_autofree gchar *month_name = g_date_time_format (self->date, "%B");
+          gtk_label_set_text (self->month_name_label, month_name);
+        }
     }
 }
 
@@ -321,8 +338,6 @@ on_breakpoint_changed_cb (GcalMonthCell *self,
     }
   else
     {
-      g_assert (G_IS_BINDING (self->icon_tooltip_binding));
-
       g_clear_pointer (&self->icon_tooltip_binding, g_binding_unbind);
       gtk_widget_set_tooltip_text (GTK_WIDGET (self->weather_icon), NULL);
     }
@@ -475,21 +490,28 @@ gcal_month_cell_set_date (GcalMonthCell *self,
 
   gcal_clear_date_time (&self->date);
   self->date = g_date_time_ref (date);
+  day_of_month = g_date_time_get_day_of_month (date);
 
   /* Day label */
-  text = g_strdup_printf ("%d", g_date_time_get_day_of_month (date));
+  text = g_strdup_printf ("%d", day_of_month);
 
   gtk_label_set_text (self->day_label, text);
   update_style_flags (self);
   add_month_separators (self);
 
   /* Month name */
-  day_of_month = g_date_time_get_day_of_month (date);
   gtk_widget_set_visible (GTK_WIDGET (self->month_name_label), day_of_month == 1);
-  if (g_date_time_get_day_of_month (date) == 1)
+  if (day_of_month == 1)
     {
-      g_autofree gchar *month_name = g_date_time_format (date, "%b");
+      g_autofree gchar *month_name = g_date_time_format (date, "%B");
       gtk_label_set_text (self->month_name_label, month_name);
+      gtk_widget_add_css_class (GTK_WIDGET (self->month_name_label), "heading");
+      gtk_widget_add_css_class (GTK_WIDGET (self->day_label), "heading");
+    }
+  else
+    {
+      gtk_widget_remove_css_class (GTK_WIDGET (self->month_name_label), "heading");
+      gtk_widget_remove_css_class (GTK_WIDGET (self->day_label), "heading");
     }
 
   update_weather (self);
@@ -592,40 +614,20 @@ gcal_month_cell_set_overflow (GcalMonthCell *self,
 gint
 gcal_month_cell_get_content_space (GcalMonthCell *self)
 {
-  GtkStyleContext *context;
-  GtkBorder padding;
-  GtkBorder border;
-
   g_return_val_if_fail (GCAL_IS_MONTH_CELL (self), -1);
 
-  context = gtk_widget_get_style_context (GTK_WIDGET (self));
-  gtk_style_context_get_padding (context, &padding);
-  gtk_style_context_get_border (context, &border);
-
   return gtk_widget_get_height (GTK_WIDGET (self)) -
-         gcal_month_cell_get_header_height (self) -
-         padding.top - padding.bottom -
-         border.top - border.bottom;
+         gcal_month_cell_get_header_height (self);
 }
 
 gint
 gcal_month_cell_get_header_height (GcalMonthCell *self)
 {
-  GtkStyleContext *context;
-  GtkBorder padding;
-  GtkBorder border;
-
   g_return_val_if_fail (GCAL_IS_MONTH_CELL (self), -1);
 
-  context = gtk_widget_get_style_context (GTK_WIDGET (self->header_box));
-  gtk_style_context_get_padding (context, &padding);
-  gtk_style_context_get_border (context, &border);
-
   return gtk_widget_get_height (self->header_box) +
          gtk_widget_get_margin_top (self->header_box) +
-         gtk_widget_get_margin_bottom (self->header_box) +
-         padding.top + padding.bottom +
-         border.top + border.bottom;
+         gtk_widget_get_margin_bottom (self->header_box);
 }
 
 gint
