@@ -74,6 +74,7 @@ struct _GcalWeekGrid
   struct {
     gint              cell;
     GtkWidget        *widget;
+    gint              event_minutes;
   } dnd;
 
   GcalContext        *context;
@@ -134,7 +135,7 @@ get_event_index (GcalRangeTree *tree,
   g_autoptr (GPtrArray) array = NULL;
   gint idx, i;
 
-  i = idx = 0;
+  idx = 0;
   array = gcal_range_tree_get_data_at_range (tree, range);
 
   if (!array)
@@ -260,13 +261,12 @@ on_click_gesture_released_cb (GtkGestureClick *click_gesture,
   g_autoptr (GcalRange) range = NULL;
   g_autoptr (GDateTime) start = NULL;
   g_autoptr (GDateTime) end = NULL;
+  graphene_point_t out;
   GtkWidget *weekview;
   gboolean ltr;
   gdouble minute_height;
   gdouble local_x;
   gdouble local_y;
-  gdouble out_x;
-  gdouble out_y;
   gint column;
   gint minute;
   gint start_cell;
@@ -318,15 +318,14 @@ on_click_gesture_released_cb (GtkGestureClick *click_gesture,
   local_x = round ((column + 0.5) * (gtk_widget_get_width (GTK_WIDGET (self)) / 7.0));
   local_y = (minute + 15) * minute_height;
 
-  gtk_widget_translate_coordinates (GTK_WIDGET (self),
-                                    weekview,
-                                    local_x,
-                                    local_y,
-                                    &out_x,
-                                    &out_y);
+  if (!gtk_widget_compute_point (GTK_WIDGET (self),
+                                 weekview,
+                                 &GRAPHENE_POINT_INIT (local_x, local_y),
+                                 &out))
+    g_assert_not_reached ();
 
   range = gcal_range_new (start, end, GCAL_RANGE_DEFAULT);
-  gcal_view_create_event (GCAL_VIEW (weekview), range, out_x, out_y);
+  gcal_view_create_event (GCAL_VIEW (weekview), range, out.x, out.y);
 
   gtk_event_controller_set_propagation_phase (self->motion_controller, GTK_PHASE_NONE);
 }
@@ -487,8 +486,19 @@ on_drop_target_motion_cb (GtkDropTarget *drop_target,
                           GcalWeekGrid  *self)
 {
   GCAL_ENTRY;
+  GcalEventWidget *event_widget;
+  const GValue *value;
+  GDateTime *start, *end;
 
   self->dnd.cell = get_dnd_cell (self, x, y);
+  value = gtk_drop_target_get_value (drop_target);
+  event_widget = g_value_get_object (value);
+
+  start = gcal_event_widget_get_date_start (event_widget);
+  end = gcal_event_widget_get_date_end (event_widget);
+
+  self->dnd.event_minutes = g_date_time_difference (end, start) / G_TIME_SPAN_MINUTE;
+
   gtk_widget_queue_allocate (GTK_WIDGET (self));
 
   GCAL_RETURN (GDK_ACTION_COPY);
@@ -610,8 +620,6 @@ gcal_week_grid_size_allocate (GtkWidget *widget,
   gboolean ltr;
   gdouble minutes_height;
   gdouble column_width;
-  guint x, y;
-  guint i;
   gint today_column;
 
   ltr = gtk_widget_get_direction (widget) != GTK_TEXT_DIR_RTL;
@@ -624,9 +632,12 @@ gcal_week_grid_size_allocate (GtkWidget *widget,
   if (gtk_widget_should_layout (self->selection.widget))
     {
       gint selection_height;
+      gint start_row;
+      gint end_row;
       gint column;
       gint start;
       gint end;
+      gint x;
       gint y;
 
       g_assert (self->selection.start != -1);
@@ -643,13 +654,16 @@ gcal_week_grid_size_allocate (GtkWidget *widget,
           start = start - end;
         }
 
-      column = start * 30 / MINUTES_PER_DAY;
+      column = (int) floor (start * 30 / (double) MINUTES_PER_DAY);
 
-#define Y_POSITION(cell_) (round (((cell_) * 30 % MINUTES_PER_DAY) * minutes_height))
+#define Y_POSITION(row_) ((gint) round (((row_) * 30) * minutes_height))
+
+      start_row = start - column * 48;
+      end_row = (end + 1) - column * 48;
 
       x = column * column_width;
-      y = Y_POSITION (start);
-      selection_height = Y_POSITION (end + 1) - y;
+      y = Y_POSITION (start_row);
+      selection_height = Y_POSITION (end_row) - y;
 
 #undef Y_POSITION
 
@@ -665,12 +679,13 @@ gcal_week_grid_size_allocate (GtkWidget *widget,
 
   if (gtk_widget_should_layout (self->dnd.widget))
     {
-      gdouble cell_height;
+      gdouble cell_height, event_height;
       gint column, row;
 
       g_assert (self->dnd.cell != -1);
 
       cell_height = minutes_height * 30;
+      event_height = minutes_height * self->dnd.event_minutes;
       column = self->dnd.cell / (MINUTES_PER_DAY / 30);
       row = self->dnd.cell - column * 48;
 
@@ -679,7 +694,7 @@ gcal_week_grid_size_allocate (GtkWidget *widget,
                                   .x = column * column_width,
                                   .y = row * cell_height,
                                   .width = column_width,
-                                  .height = cell_height,
+                                  .height = event_height,
                                 },
                                 baseline);
     }
@@ -693,7 +708,7 @@ gcal_week_grid_size_allocate (GtkWidget *widget,
    * Iterate through weekdays; we don't have to worry about events that
    * jump between days because they're already handled by GcalWeekHeader.
    */
-  for (i = 0; i < 7; i++)
+  for (size_t i = 0; i < 7; i++)
     {
       g_autoptr (GcalRange) day_range = NULL;
       GPtrArray *widgets_data;
@@ -720,6 +735,8 @@ gcal_week_grid_size_allocate (GtkWidget *widget,
           gint offset;
           gint event_height;
           gint event_width;
+          gint x;
+          gint y;
 
           data =  g_ptr_array_index (widgets_data, j);
           event_widget = data->widget;
@@ -788,6 +805,7 @@ gcal_week_grid_size_allocate (GtkWidget *widget,
       GtkAllocation allocation;
       guint minutes_from_midnight;
       gint now_strip_height;
+      gint x;
 
       now = g_date_time_new_now_local ();
       minutes_from_midnight = g_date_time_get_hour (now) * 60 + g_date_time_get_minute (now);
@@ -876,6 +894,7 @@ gcal_week_grid_init (GcalWeekGrid *self)
   gtk_widget_add_controller (GTK_WIDGET (self), self->motion_controller);
 
   drop_target = gtk_drop_target_new (GCAL_TYPE_EVENT_WIDGET, GDK_ACTION_COPY);
+  gtk_drop_target_set_preload (drop_target, TRUE);
   g_signal_connect (drop_target, "drop", G_CALLBACK (on_drop_target_drop_cb), self);
   g_signal_connect (drop_target, "enter", G_CALLBACK (on_drop_target_enter_cb), self);
   g_signal_connect (drop_target, "leave", G_CALLBACK (on_drop_target_leave_cb), self);
