@@ -617,41 +617,6 @@ e_utf8_strftime_fix_am_pm (gchar *str,
   return sz;
 }
 
-/**
- * get_source_parent_name_color:
- * @manager: a #GcalManager
- * @source: an #ESource
- * @name: (nullable): return location for the name
- * @color: (nullable): return location for the color
- *
- * Retrieves the name and the color of the #ESource that is
- * parent of @source.
- */
-void
-get_source_parent_name_color (GcalManager  *manager,
-                              ESource      *source,
-                              gchar       **name,
-                              gchar       **color)
-{
-  ESource *parent_source;
-
-  g_assert (source && E_IS_SOURCE (source));
-
-  parent_source = gcal_manager_get_source (manager, e_source_get_parent (source));
-
-  if (name != NULL)
-    *name = e_source_dup_display_name (parent_source);
-
-  if (color != NULL)
-    {
-      GdkRGBA c;
-
-      get_color_name_from_source (parent_source, &c);
-
-      *color = gdk_rgba_to_string (&c);
-    }
-}
-
 /**
  * format_utc_offset:
  * @offset: an UTC offset
@@ -1271,11 +1236,26 @@ gcal_get_service_name_from_url (const gchar *url)
     const gchar *needle;
     const gchar *service_name;
   } service_name_vtable[] = {
+    // Conferencing
+    { "bluejeans", N_("BlueJeans") },
+    { "bigbluebutton", N_("BigBlueButton") },
+    { "bbb", N_("BigBlueButton") },
     { "meet.google.com", N_("Google Meet") },
     { "meet.jit.si", N_("Jitsi") },
-    { "whereby.com", N_("Whereby") },
-    { "zoom.us", N_("Zoom") },
+    { "jitsi", N_("Jitsi") },
+    { "meetings.dialpad.com", N_("Uber Conference") },
+    { "meet.gnome.com", N_("GNOME Meet") },
     { "teams.microsoft.com", N_("Microsoft Teams") },
+    { "whereby.com", N_("Whereby") },
+    { "webex", N_("Webex") },
+    { "zoom.us", N_("Zoom") },
+
+    // Map
+    { "geo:", N_("View Map") },
+    { "openstreetmap.org", N_("OpenStreetMap") },
+    { "maps.app.goo.gl", N_("Google Maps") },
+    { "google.com/maps", N_("Google Maps") },
+    { "bing.com/maps", N_("Bing Maps") },
   };
   gsize i;
 
